@@ -747,7 +747,7 @@ def surface(
 # noinspection PyShadowingNames
 def text(
         text,
-        position=(0, 0, 0),
+        position=[0, 0, 0],
         color=_default_color,
         reference_point="lb",
         on_top=True,
@@ -764,10 +764,11 @@ def text(
 
     Parameters
     ----------
-    text : str
-        Text content.
-    position : tuple, optional
+    text: str or list of str
+        Content of the text.
+    position : list
         (x, y, z) coordinates of text position, by default (0, 0, 0).
+        If n text is pass position should contain 3*n elements .
     color : int, optional
         Hex color of the text, by default _default_color.
     reference_point : str, optional
@@ -845,10 +846,11 @@ def text2d(
 
     Parameters
     ----------
-    text : str
+    text : str or list of str
         Text content.
     position : tuple, optional
         (rx, ry) text position ratios in range (0, 1) - relative to canvas size, by default (0, 0).
+        If n text is pass position should contain 2*n elements .
     color : int, optional
         Hex color of the text, by default _default_color.
     reference_point : str, optional
@@ -923,10 +925,11 @@ def label(
 
     Parameters
     ----------
-    text : str
-        Text content.
-    position : tuple, optional
+    text: str or list of str
+        Content of the text.
+    position : list
         (x, y, z) coordinates of text position, by default (0, 0, 0).
+        If n text is pass position should contain 3*n elements .
     color : int, optional
         Hex color of the text, by default _default_color.
     on_top : bool, optional
@@ -1093,10 +1096,11 @@ def texture_text(
 
     Parameters
     ----------
-    text : str
-        Text content.
-    position : tuple, optional
+    text: str or list of str
+        Content of the text.
+    position : list
         (x, y, z) coordinates of text position, by default (0, 0, 0).
+        If n text is pass position should contain 3*n elements .
     color : int, optional
         Hex color of the text, by default _default_color.
     font_weight : int, optional
@@ -1587,6 +1591,8 @@ def volume(
         focal_length=0.0,
         focal_plane=100.0,
         ray_samples_count=16,
+        mask=[],
+        mask_opacities=[],
         name=None,
         group=None,
         custom_data=None,
@@ -1637,6 +1643,10 @@ def volume(
         Focal plane of depth of field renderer, by default 100.0.
     ray_samples_count : int, optional
         Number of rays for depth of field rendering, by default 16.
+    mask: `array_like`.
+        3D array of `int` in range (0, 255).
+    mask_opacities: `array_like`.
+        List of opacity values for mask.
     name : str, optional
         Object name, by default None.
     group : str, optional
@@ -1682,6 +1692,8 @@ def volume(
             shadow_res=shadow_res,
             focal_plane=focal_plane,
             focal_length=focal_length,
+            mask=mask,
+            mask_opacities=mask_opacities,
             name=name,
             group=group,
             custom_data=custom_data,
@@ -1699,6 +1711,9 @@ def mip(
         color_range=[],
         samples=512.0,
         gradient_step=0.005,
+        interpolation=True,
+        mask=[],
+        mask_opacities=[],
         name=None,
         group=None,
         custom_data=None,
@@ -1733,6 +1748,12 @@ def mip(
         Number of iteration per 1 unit of space, by default 512.0.
     gradient_step : float, optional
         Gradient light step, by default 0.005.
+    interpolation : bool, optional
+        Interpolate volume raycasting data, by default True.
+    mask: `array_like`.
+        3D array of `int` in range (0, 255).
+    mask_opacities: `array_like`.
+        List of opacity values for mask.
     name : str, optional
         Object name, by default None.
     group : str, optional
@@ -1770,6 +1791,9 @@ def mip(
             color_range=color_range,
             samples=samples,
             gradient_step=gradient_step,
+            interpolation=interpolation,
+            mask=mask,
+            mask_opacities=mask_opacities,
             name=name,
             group=group,
             custom_data=custom_data,
@@ -1993,6 +2017,7 @@ def plot(
         camera_pan_speed=0.3,
         camera_damping_factor=0.0,
         fps=25.0,
+        minimum_fps=-1,
         fps_meter=False,
         name=None,
         custom_data=None
@@ -2065,6 +2090,8 @@ def plot(
         Camera intensity of damping, by default 0.0.
     fps : float, optional
         Animations FPS, by default 25.0.
+    minimum_fps: `Float`.
+            If negative then disabled. Set target FPS to adaptative resolution.
     custom_data: `dict`
         A object with custom data attached to object.
 
@@ -2106,6 +2133,7 @@ def plot(
         camera_pan_speed=camera_pan_speed,
         auto_rendering=auto_rendering,
         fps=fps,
+        minimum_fps=minimum_fps,
         fps_meter=fps_meter,
         custom_data=custom_data
     )
