@@ -1,7 +1,6 @@
-import warnings
-
 import ipywidgets as widgets
 import numpy as np
+import warnings
 from traitlets import (
     Any,
     Bool,
@@ -41,6 +40,11 @@ class TimeSeries(Union):
             Union.__init__(self, [trait, Dict(trait)])
 
 
+class SingleOrList(Union):
+    def __init__(self, trait):
+        Union.__init__(self, [trait, List(trait)])
+
+
 class ListOrArray(List):
     _cast_types = (tuple, np.ndarray)
 
@@ -745,7 +749,7 @@ class STL(Drawable):
     type = Unicode(read_only=True).tag(sync=True)
     text = AsciiStlData(allow_none=True, default_value=None).tag(sync=True)
     binary = BinaryStlData(allow_none=True,
-                           default_value=None).tag(sync=True, **array_serialization_wrap("binary"))
+        default_value=None).tag(sync=True, **array_serialization_wrap("binary"))
     color = Int(min=0, max=0xFFFFFF).tag(sync=True)
     wireframe = Bool().tag(sync=True)
     flat_shading = Bool().tag(sync=True)
@@ -825,10 +829,11 @@ class Text(Drawable):
     Text rendered using KaTeX with a 3D position.
 
     Attributes:
-        text: `str`.
+        text: str or list of str
             Content of the text.
-        position: `list`.
-            Coordinates (x, y, z) of the text's position.
+        position : list
+            (x, y, z) coordinates of text position, by default (0, 0, 0).
+            If n text is pass position should contain 3*n elements .
         color: `int`.
             Packed RGB color of the text (0xff0000 is red, 0xff is blue).
         is_html: `Boolean`.
@@ -850,8 +855,8 @@ class Text(Drawable):
     """
 
     type = Unicode(read_only=True).tag(sync=True)
-    text = TimeSeries(Unicode()).tag(sync=True)
-    position = TimeSeries(ListOrArray(minlen=3, maxlen=3)).tag(sync=True)
+    text = TimeSeries(SingleOrList(Unicode())).tag(sync=True)
+    position = TimeSeries(Array(dtype=np.float32)).tag(sync=True, **array_serialization_wrap("position"))
     is_html = Bool(False).tag(sync=True)
     color = Int(min=0, max=0xFFFFFF).tag(sync=True)
     reference_point = Unicode().tag(sync=True)
@@ -876,10 +881,11 @@ class Text2d(Drawable):
     Text rendered using KaTeX with a fixed 2D position, independent of camera settings.
 
     Attributes:
-        text: `str`.
+        text: str or list of str
             Content of the text.
         position: `list`.
             Ratios (r_x, r_y) of the text's position in range (0, 1) - relative to canvas size.
+            If n text is pass position should contain 2*n elements .
         color: `int`.
             Packed RGB color of the text (0xff0000 is red, 0xff is blue).
         is_html: `Boolean`.
@@ -897,12 +903,12 @@ class Text2d(Drawable):
     """
 
     type = Unicode(read_only=True).tag(sync=True)
-    color = Int(min=0, max=0xFFFFFF).tag(sync=True)
-    size = TimeSeries(Float(min=EPSILON, default_value=1.0)).tag(sync=True)
+    text = TimeSeries(SingleOrList(Unicode())).tag(sync=True)
+    position = TimeSeries(Array(dtype=np.float32)).tag(sync=True, **array_serialization_wrap("position"))
     is_html = Bool(False).tag(sync=True)
+    color = Int(min=0, max=0xFFFFFF).tag(sync=True)
     reference_point = Unicode().tag(sync=True)
-    position = TimeSeries(ListOrArray(minlen=2, maxlen=2)).tag(sync=True)
-    text = TimeSeries(Unicode()).tag(sync=True)
+    size = TimeSeries(Float(min=EPSILON, default_value=1.0)).tag(sync=True)
     label_box = Bool().tag(sync=True)
 
     def __init__(self, **kwargs):
@@ -919,10 +925,11 @@ class Label(Drawable):
     Label rendered using KaTeX with a 3D position.
 
     Attributes:
-        text: `str`.
+        text: str or list of str
             Content of the text.
-        position: `list`.
-            Coordinates (x, y, z) of the text's position.
+        position : list
+            (x, y, z) coordinates of text position, by default (0, 0, 0).
+            If n text is pass position should contain 3*n elements .
         color: `int`.
             Packed RGB color of the text (0xff0000 is red, 0xff is blue).
         on_top: `Boolean`.
@@ -943,9 +950,9 @@ class Label(Drawable):
 
     type = Unicode(read_only=True).tag(sync=True)
     mode = Unicode().tag(sync=True)
-    text = TimeSeries(Unicode()).tag(sync=True)
+    text = TimeSeries(SingleOrList(Unicode())).tag(sync=True)
     is_html = Bool(False).tag(sync=True)
-    position = TimeSeries(ListOrArray(minlen=3, maxlen=3)).tag(sync=True)
+    position = TimeSeries(Array(dtype=np.float32)).tag(sync=True, **array_serialization_wrap("position"))
     color = Int(min=0, max=0xFFFFFF).tag(sync=True)
     max_length = Float(min=0, max=1.0).tag(sync=True)
     size = TimeSeries(Float(min=EPSILON, default_value=1.0)).tag(sync=True)
@@ -1035,10 +1042,11 @@ class TextureText(Drawable):
     many simple labels need to be displayed.
 
     Attributes:
-        text: `str`.
+        text: str or list of str
             Content of the text.
-        position: `list`.
-            Coordinates (x, y, z) of the text's position.
+        position : list
+            (x, y, z) coordinates of text position, by default (0, 0, 0).
+            If n text is pass position should contain 3*n elements .
         color: `int`.
             Packed RGB color of the text (0xff0000 is red, 0xff is blue).
         size: `float`.
@@ -1056,8 +1064,8 @@ class TextureText(Drawable):
     """
 
     type = Unicode(read_only=True).tag(sync=True)
-    text = TimeSeries(Unicode()).tag(sync=True)
-    position = TimeSeries(ListOrArray(minlen=3, maxlen=3)).tag(sync=True)
+    text = TimeSeries(SingleOrList(Unicode())).tag(sync=True)
+    position = TimeSeries(Array(dtype=np.float32)).tag(sync=True, **array_serialization_wrap("position"))
     color = TimeSeries(Int(min=0, max=0xFFFFFF)).tag(sync=True)
     size = TimeSeries(Float(min=EPSILON, default_value=1.0)).tag(sync=True)
     font_face = Unicode().tag(sync=True)
@@ -1253,6 +1261,10 @@ class Volume(Drawable):
             Resolution of shadow map.
         interpolation: `bool`.
             Whether volume raycasting should interpolate data or not.
+        mask: `array_like`.
+            3D array of `int` in range (0, 255).
+        mask_opacities: `array_like`.
+            List of opacity values for mask.
         model_matrix: `array_like`.
             4x4 model transform matrix.
     """
@@ -1281,6 +1293,9 @@ class Volume(Drawable):
     focal_length = TimeSeries(Float()).tag(sync=True)
     focal_plane = TimeSeries(Float()).tag(sync=True)
     interpolation = TimeSeries(Bool()).tag(sync=True)
+    mask = Array(dtype=np.uint8).tag(sync=True, **array_serialization_wrap('mask'))
+    mask_opacities = TimeSeries(Array(dtype=np.float32)).tag(sync=True, **array_serialization_wrap(
+        'mask_opacities'))
     model_matrix = TimeSeries(Array(dtype=np.float32)).tag(
         sync=True, **array_serialization_wrap("model_matrix")
     )
@@ -1342,6 +1357,10 @@ class MIP(Drawable):
             Number of iteration per 1 unit of space.
         gradient_step: `float`
             Gradient light step.
+        mask: `array_like`.
+            3D array of `int` in range (0, 255).
+        mask_opacities: `array_like`.
+            List of opacity values for mask.
         model_matrix: `array_like`.
             4x4 model transform matrix.
     """
@@ -1360,6 +1379,10 @@ class MIP(Drawable):
     )
     gradient_step = TimeSeries(Float()).tag(sync=True)
     samples = TimeSeries(Float()).tag(sync=True)
+    interpolation = TimeSeries(Bool()).tag(sync=True)
+    mask = Array(dtype=np.uint8).tag(sync=True, **array_serialization_wrap('mask'))
+    mask_opacities = TimeSeries(Array(dtype=np.float32)).tag(sync=True, **array_serialization_wrap(
+        'mask_opacities'))
     model_matrix = TimeSeries(Array(dtype=np.float32)).tag(
         sync=True, **array_serialization_wrap("model_matrix")
     )
